@@ -1,21 +1,23 @@
 import uuid
 import jmespath
 
-
 class Instance(object):
     def __init__(
         self,
         id: str = None,
-        prediction: int = 0,
-        confidence: float = 1.0,
-        image: str = None,
+        prediction: int = None,
+        confidence: float = None,
+        files: list = None,
         metadata: dict = None,
         properties: dict = None,
     ) -> None:
         self.id = id or uuid.uuid4().hex
         self.prediction = prediction
         self.confidence = confidence
-        self.image = image
+        self.files = files
+
+        if self.files and not isinstance(self.files, list):
+            self.files = [self.files]
 
         if metadata is not None and not isinstance(metadata, dict):
             raise ValueError("The field 'metadata' must be a dictionary.")
@@ -56,16 +58,23 @@ class Instance(object):
         return expression
 
     def to_dict(self):
-        return self.__dict__
+        result = self.__dict__.copy()
+
+        # Remove the private attribute representing the image
+        # and add the value of the property.
+        if "_Instance__image" in result:
+            del result["_Instance__image"]
+
+        return result
 
     @staticmethod
     def create(data):
         data = data.copy()
 
         id = data.get("id", None)
-        prediction = data.get("prediction", 1)
-        confidence = data.get("confidence", 1.0)
-        image = data.get("image", None)
+        prediction = data.get("prediction", None)
+        confidence = data.get("confidence", None)
+        files = data.get("files", None)
 
         if "id" in data:
             del data["id"]
@@ -76,8 +85,8 @@ class Instance(object):
         if "confidence" in data:
             del data["confidence"]
 
-        if "image" in data:
-            del data["image"]
+        if "files" in data:
+            del data["files"]
 
         if "metadata" in data:
             metadata = data["metadata"]
@@ -98,7 +107,7 @@ class Instance(object):
             id=id,
             prediction=prediction,
             confidence=confidence,
-            image=image,
+            files=files,
             metadata=metadata,
             properties=properties,
         )
