@@ -27,7 +27,7 @@ class Flagging(module.Module):
         )
         self.threshold = threshold
 
-    def run(self, instance: dict):
+    def run(self, instance: dict, **kwargs):
         confidence = instance.confidence
         return {"flagged": int(confidence < self.threshold)}
 
@@ -75,7 +75,7 @@ class CostSensitiveFlagging(module.Module):
         self.fn_cost = fn_cost or 0
         self.human_review_cost = human_review_cost or 0
 
-    def run(self, instance: Instance):
+    def run(self, instance: Instance, **kwargs):
         """Processes the supplied instance and returns a field indicating
         whether the instance should be sent for human review together with
         the computed costs.
