@@ -16,7 +16,7 @@ class Map(Module):
 
         self.function = function
 
-    def run(self, instance: Instance):
+    def run(self, instance: Instance, **kwargs):
         fn = self._load_function(self.function)
         if fn is None:
             raise RuntimeError(f"Unable to load function {self.function}")
