@@ -4,11 +4,13 @@ import yaml
 import sys
 import importlib.util
 import redis
+import re
 
 from rq import Queue, Retry
 from importlib import import_module
 
 from alira.instance import Instance
+from alira.modules.module import InternalError
 from alira.store import Store
 
 rq_worker_logger = logging.getLogger("rq.worker")
@@ -40,6 +42,7 @@ class Pipeline(object):
         # modules from the pipeline.yml file.
         self.pipeline_id = None
         self.modules = None
+        self.dependencies = None
 
         self._load_pipeline_configuration(pipeline_configuration)
 
@@ -56,6 +59,7 @@ class Pipeline(object):
             redis_connection = redis.from_url(self.redis_server)
         else:
             import fakeredis
+
             redis_connection = fakeredis.FakeStrictRedis()
 
         queue = Queue(
@@ -82,6 +86,7 @@ class Pipeline(object):
                 module=module,
                 module_signature=module_signature,
                 instance=instance,
+                dependencies=self.dependencies,
                 store_configuration=self.store_configuration,
                 pipeline_id=self.pipeline_id,
                 configuration_directory=self.configuration_directory,
@@ -100,6 +105,7 @@ class Pipeline(object):
         module,
         module_signature,
         instance,
+        dependencies,
         store_configuration,
         pipeline_id,
         configuration_directory,
@@ -115,24 +121,33 @@ class Pipeline(object):
 
         instance = store.get(instance.id) or instance
         rq_worker_logger.debug(f"Input instance: {instance.to_dict()}")
-
-        result = module.run(instance)
-
-        if result is None:
-            return None
+        rq_worker_logger.debug(f"Dependencies: {dependencies}")
 
         module_name = (
             module.module_id if hasattr(module, "module_id") else module_signature
         )
 
-        module_output = {module_name: result}
+        try:
+            result = module.run(instance, **dependencies)
+
+            if result is None:
+                return None
+
+            module_output = {module_name: result}
+        except TypeError as e:
+            error = f"Unable to run module: {e}"
+            rq_worker_logger.exception(error)
+            module_output = {module_name: error}
+        except InternalError as e:
+            error = f"Internal Exception: {e}"
+            rq_worker_logger.exception(error)
+            module_output = {module_name: error}
 
         instance = store.get(instance.id) or instance
         instance.properties.update(module_output)
         store.put(instance)
 
         rq_worker_logger.debug(f"Output instance: {instance.to_dict()}")
-
         return module_output
 
     @classmethod
@@ -184,14 +199,16 @@ class Pipeline(object):
                 "the configuration."
             )
 
-        self.modules = []
-        pipeline = pipeline_configuration.get("pipeline", [])
+        self.modules = list(
+            self._load_modules(pipeline_configuration, "pipeline").values()
+        )
+        self.dependencies = self._load_modules(pipeline_configuration, "dependencies")
 
-        for module_configuration in pipeline:
+    def _load_modules(self, pipeline_configuration, section: str):
+        result = {}
+        for section_data in pipeline_configuration.get(section, []):
             try:
-                module_path, _, module_name = module_configuration["module"].rpartition(
-                    "."
-                )
+                module_path, _, module_name = section_data["module"].rpartition(".")
                 module = getattr(import_module(module_path), module_name)
                 logging.info(f"Loaded module {module_path}.{module_name}")
             except ModuleNotFoundError as e:
@@ -204,14 +221,27 @@ class Pipeline(object):
                 "configuration_directory": self.configuration_directory,
             }
 
-            for argument_id, argument in module_configuration.items():
+            for argument_id, argument in section_data.items():
                 if argument_id == "module":
                     continue
 
                 arguments[argument_id] = argument
 
             arguments.update(self.kwargs)
-            self.modules.append(module(**arguments))
+
+            # Every module should have a `reference`. This will be the configured
+            # `module_id` or a snake_case name based on the module name.
+            if "module_id" in arguments:
+                reference = arguments["module_id"]
+            else:
+                reference = re.sub("(.)([A-Z][a-z]+)", r"\1_\2", module_name)
+                reference = re.sub("([a-z0-9])([A-Z])", r"\1_\2", reference).lower()
+                while reference in result:
+                    reference += "_"
+
+            result[reference] = module(**arguments)
+
+        return result
 
     def _load_pipeline_configuration_from_stream(self, pipeline_configuration):
         try:
